@@ -11,6 +11,7 @@ from simplipy.errors import InvalidCredentialsError, RequestError
 from simplipy.system import System
 from simplipy.system.v2 import SystemV2
 from simplipy.system.v3 import SystemV3
+from simplipy.websocket import Websocket
 
 _LOGGER: logging.Logger = logging.getLogger(__name__)
 
@@ -19,8 +20,8 @@ DEFAULT_AUTH_USERNAME: str = "{0}.2074.0.0.com.simplisafe.mobile"
 
 SYSTEM_MAP: Dict[int, Type[System]] = {2: SystemV2, 3: SystemV3}
 
-URL_HOSTNAME: str = "api.simplisafe.com"
-URL_BASE: str = f"https://{URL_HOSTNAME}/v1"
+API_URL_HOSTNAME: str = "api.simplisafe.com"
+API_URL_BASE: str = f"https://{API_URL_HOSTNAME}/v1"
 
 ApiType = TypeVar("ApiType", bound="API")
 
@@ -38,7 +39,8 @@ class API:  # pylint: disable=too-many-instance-attributes
         self._websession: ClientSession = websession
         self.email: Optional[str] = None
         self.refresh_token_dirty: bool = False
-        self.user_id: Optional[str] = None
+        self.user_id: Optional[int] = None
+        self.websocket: Optional[Websocket] = None
 
     @property
     def refresh_token(self) -> str:
@@ -80,45 +82,9 @@ class API:  # pylint: disable=too-many-instance-attributes
         await klass.refresh_access_token(refresh_token)
         return klass
 
-    async def authenticate(self, payload_data: dict) -> None:
-        """Request token data and parse it."""
-        token_resp: dict = await self.request(
-            "post",
-            "api/token",
-            data=payload_data,
-            auth=BasicAuth(
-                login=DEFAULT_AUTH_USERNAME.format(self._uuid),
-                password="",
-                encoding="latin1",
-            ),
-        )
-
-        self._access_token = token_resp["access_token"]
-        self._access_token_expire = datetime.now() + timedelta(
-            seconds=int(token_resp["expires_in"]) - 60
-        )
-        self.refresh_token = token_resp["refresh_token"]
-
-        auth_check_resp: dict = await self.request("get", "api/authCheck")
-        self.user_id = auth_check_resp["userId"]
-
-    async def get_systems(self) -> Dict[str, System]:
-        """Get systems associated to this account."""
-        subscription_resp: dict = await self.get_subscription_data()
-
-        systems: Dict[str, System] = {}
-        for system_data in subscription_resp["subscriptions"]:
-            version = system_data["location"]["system"]["version"]
-            system_class = SYSTEM_MAP[version]
-            system = system_class(self, system_data["location"])
-            await system.update(refresh_location=False)
-            systems[system_data["sid"]] = system
-
-        return systems
-
-    async def get_subscription_data(self) -> dict:
+    async def _get_subscription_data(self) -> dict:
         """Get the latest location-level data."""
-        subscription_resp: dict = await self.request(
+        subscription_resp: dict = await self._request(
             "get", f"users/{self.user_id}/subscriptions", params={"activeOnly": "true"}
         )
 
@@ -126,19 +92,7 @@ class API:  # pylint: disable=too-many-instance-attributes
 
         return subscription_resp
 
-    async def refresh_access_token(self, refresh_token: str) -> None:
-        """Regenerate an access token."""
-        await self.authenticate(
-            {
-                "grant_type": "refresh_token",
-                "username": self.email,
-                "refresh_token": refresh_token,
-            }
-        )
-
-        self._actively_refreshing = False
-
-    async def request(
+    async def _request(
         self,
         method: str,
         endpoint: str,
@@ -162,12 +116,12 @@ class API:  # pylint: disable=too-many-instance-attributes
             headers = {}
         if not kwargs.get("auth") and self._access_token:
             headers["Authorization"] = f"Bearer {self._access_token}"
-        headers.update({"Host": URL_HOSTNAME, "User-Agent": DEFAULT_USER_AGENT})
+        headers.update({"Host": API_URL_HOSTNAME, "User-Agent": DEFAULT_USER_AGENT})
 
         try:
             async with self._websession.request(
                 method,
-                f"{URL_BASE}/{endpoint}",
+                f"{API_URL_BASE}/{endpoint}",
                 headers=headers,
                 params=params,
                 data=data,
@@ -185,7 +139,7 @@ class API:  # pylint: disable=too-many-instance-attributes
                 if self._refresh_token:
                     _LOGGER.info("401 detected; attempting refresh token")
                     self._access_token_expire = datetime.now()
-                    return await self.request(
+                    return await self._request(
                         method,
                         endpoint,
                         headers=headers,
@@ -204,3 +158,58 @@ class API:  # pylint: disable=too-many-instance-attributes
                 )
 
             raise RequestError(f"Error requesting data from {endpoint}: {err}")
+
+    async def authenticate(self, payload_data: dict) -> None:
+        """Request token data and parse it."""
+        token_resp: dict = await self._request(
+            "post",
+            "api/token",
+            data=payload_data,
+            auth=BasicAuth(
+                login=DEFAULT_AUTH_USERNAME.format(self._uuid),
+                password="",
+                encoding="latin1",
+            ),
+        )
+
+        self._access_token = token_resp["access_token"]
+        self._access_token_expire = datetime.now() + timedelta(
+            seconds=int(token_resp["expires_in"]) - 60
+        )
+        self.refresh_token = token_resp["refresh_token"]
+
+        auth_check_resp: dict = await self._request("get", "api/authCheck")
+        self.user_id = auth_check_resp["userId"]
+
+        if self.websocket:
+            self.websocket.access_token = self._access_token
+        else:
+            self.websocket = Websocket(self._access_token, self.user_id)  # type: ignore
+
+    async def get_systems(self) -> Dict[str, System]:
+        """Get systems associated to this account."""
+        subscription_resp: dict = await self._get_subscription_data()
+
+        systems: Dict[str, System] = {}
+        for system_data in subscription_resp["subscriptions"]:
+            version = system_data["location"]["system"]["version"]
+            system_class = SYSTEM_MAP[version]
+            system = system_class(
+                system_data["location"], self._request, self._get_subscription_data
+            )
+            await system.update(include_system=False, cached=False)
+            systems[system_data["sid"]] = system
+
+        return systems
+
+    async def refresh_access_token(self, refresh_token: str) -> None:
+        """Regenerate an access token."""
+        await self.authenticate(
+            {
+                "grant_type": "refresh_token",
+                "username": self.email,
+                "refresh_token": refresh_token,
+            }
+        )
+
+        self._actively_refreshing = False
